     //////////////////////////////////////////////////////////////////////
     // The contents of this file are subject to the Mozilla Public License
     // Version 1.1 (the "License"); you may not use this file except in
     // compliance with the License.  You may obtain a copy of the License
     // at http://www.mozilla.org/MPL/
     //
     // Software distributed under the License is distributed on an "AS IS"
     // basis, WITHOUT WARRANTY OF ANY KIND, either express or implied.
     // See the License for the specific language governing rights and
     // limitations under the License.
     //
     // The Original Code is "Mini".
     //
     // The Initial Developer of the Original Code is David Wallace Croft
     // (croft@alumni.caltech.edu, http://www.alumni.caltech.edu/~croft/).
     // Portions created by David Wallace Croft are
     // Copyright (C) 1999 David Wallace Croft.  All Rights Reserved.
     //
     // Contributor(s):
     //////////////////////////////////////////////////////////////////////

     package com.orbs.open.a.mpl.compiler.mini.node;

     import java.util.*;

     /*********************************************************************
     * Parse tree node for the Mini programming language.
     *
     * @see
     *   MiniNode
     *
     * @author
     *   <A HREF="http://www.alumni.caltech.edu/~croft/">David W. Croft</A>
     * @version
     *   1999-04-25
     *********************************************************************/

     public class  ConditionalStatementMiniNode extends AbstractMiniNode
       implements StatementMiniNode
     //////////////////////////////////////////////////////////////////////
     //////////////////////////////////////////////////////////////////////
     {

     protected ComparisonMiniNode         comparisonMiniNode;
     protected StatementSequenceMiniNode  thenStatementSequenceMiniNode;
     protected StatementSequenceMiniNode  elseStatementSequenceMiniNode;

     //////////////////////////////////////////////////////////////////////
     //////////////////////////////////////////////////////////////////////

     public  ConditionalStatementMiniNode (
       ComparisonMiniNode         comparisonMiniNode,
       StatementSequenceMiniNode  thenStatementSequenceMiniNode,
       StatementSequenceMiniNode  elseStatementSequenceMiniNode )
     //////////////////////////////////////////////////////////////////////
     {
       this.comparisonMiniNode            = comparisonMiniNode;
       this.thenStatementSequenceMiniNode = thenStatementSequenceMiniNode;
       this.elseStatementSequenceMiniNode = elseStatementSequenceMiniNode;
     }

     public  ConditionalStatementMiniNode (
       ComparisonMiniNode         comparisonMiniNode,
       StatementSequenceMiniNode  thenStatementSequenceMiniNode )
     //////////////////////////////////////////////////////////////////////
     {
       this ( comparisonMiniNode, thenStatementSequenceMiniNode, null );
     }

     //////////////////////////////////////////////////////////////////////
     //////////////////////////////////////////////////////////////////////

     public ComparisonMiniNode  getComparisonMiniNode ( )
     //////////////////////////////////////////////////////////////////////
     {
       return comparisonMiniNode;
     }

     public StatementSequenceMiniNode  getThenStatementSequenceMiniNode ( )
     //////////////////////////////////////////////////////////////////////
     {
       return thenStatementSequenceMiniNode;
     }

     public StatementSequenceMiniNode  getElseStatementSequenceMiniNode ( )
     //////////////////////////////////////////////////////////////////////
     {
       return elseStatementSequenceMiniNode;
     }

     //////////////////////////////////////////////////////////////////////
     // MiniNode interface methods
     //////////////////////////////////////////////////////////////////////

     public void  generate ( MiniNodeCodeVisitor  miniNodeCodeVisitor )
     //////////////////////////////////////////////////////////////////////
     {
       miniNodeCodeVisitor.generateConditionalStatement ( this );
     }
     
     public void  checkSemantics ( Stack  parentMiniNodeStack )
       throws SemanticErrorException
     //////////////////////////////////////////////////////////////////////
     {
       parentMiniNodeStack.push ( this );

       comparisonMiniNode.checkSemantics ( parentMiniNodeStack );

       if ( thenStatementSequenceMiniNode != null )
       {
         thenStatementSequenceMiniNode.checkSemantics (
           parentMiniNodeStack );
       }

       if ( elseStatementSequenceMiniNode != null )
       {
         elseStatementSequenceMiniNode.checkSemantics (
           parentMiniNodeStack );
       }

       parentMiniNodeStack.pop ( );
     }

     //////////////////////////////////////////////////////////////////////
     //////////////////////////////////////////////////////////////////////
     }
