     //////////////////////////////////////////////////////////////////////
     // The contents of this file are subject to the Mozilla Public License
     // Version 1.1 (the "License"); you may not use this file except in
     // compliance with the License.  You may obtain a copy of the License
     // at http://www.mozilla.org/MPL/
     //
     // Software distributed under the License is distributed on an "AS IS"
     // basis, WITHOUT WARRANTY OF ANY KIND, either express or implied.
     // See the License for the specific language governing rights and
     // limitations under the License.
     //
     // The Original Code is "Mini".
     //
     // The Initial Developer of the Original Code is David Wallace Croft
     // (croft@alumni.caltech.edu, http://www.alumni.caltech.edu/~croft/).
     // Portions created by David Wallace Croft are
     // Copyright (C) 1999 David Wallace Croft.  All Rights Reserved.
     //
     // Contributor(s):
     //////////////////////////////////////////////////////////////////////

     package com.orbs.open.a.mpl.compiler.mini.node;

     import java.util.*;

     /*********************************************************************
     * Parse tree node for the Mini programming language.
     *
     * @see
     *   MiniNode
     *
     * @author
     *   <A HREF="http://www.alumni.caltech.edu/~croft/">David W. Croft</A>
     * @version
     *   1999-04-25
     *********************************************************************/

     public class  TermMiniNode extends AbstractMiniNode
     //////////////////////////////////////////////////////////////////////
     //////////////////////////////////////////////////////////////////////
     {

     protected TermMiniNode      termMiniNode;
     protected OperatorMiniNode  operatorMiniNode;
     protected ElementMiniNode   elementMiniNode;

     //////////////////////////////////////////////////////////////////////
     //////////////////////////////////////////////////////////////////////

     public  TermMiniNode (
       TermMiniNode      termMiniNode,
       OperatorMiniNode  operatorMiniNode,
       ElementMiniNode   elementMiniNode )
     //////////////////////////////////////////////////////////////////////
     {
       this.termMiniNode     = termMiniNode;
       this.operatorMiniNode = operatorMiniNode;
       this.elementMiniNode  = elementMiniNode;
     }

     public  TermMiniNode ( ElementMiniNode  elementMiniNode )
     //////////////////////////////////////////////////////////////////////
     {
       this ( null, null, elementMiniNode );
     }

     //////////////////////////////////////////////////////////////////////
     //////////////////////////////////////////////////////////////////////

     public TermMiniNode  getTermMiniNode ( )
     //////////////////////////////////////////////////////////////////////
     {
       return termMiniNode;
     }

     public OperatorMiniNode  getOperatorMiniNode ( )
     //////////////////////////////////////////////////////////////////////
     {
       return operatorMiniNode;
     }

     public ElementMiniNode  getElementMiniNode ( )
     //////////////////////////////////////////////////////////////////////
     {
       return elementMiniNode;
     }

     //////////////////////////////////////////////////////////////////////
     // MiniNode interface methods
     //////////////////////////////////////////////////////////////////////

     public void  generate ( MiniNodeCodeVisitor  miniNodeCodeVisitor )
     //////////////////////////////////////////////////////////////////////
     {
       miniNodeCodeVisitor.generateTerm ( this );
     }
     
     public void  checkSemantics ( Stack  parentMiniNodeStack )
       throws SemanticErrorException
     //////////////////////////////////////////////////////////////////////
     {
       parentMiniNodeStack.push ( this );

       if ( termMiniNode != null )
       {
         termMiniNode.checkSemantics ( parentMiniNodeStack );
       }

       if ( operatorMiniNode != null )
       {
         operatorMiniNode.checkSemantics ( parentMiniNodeStack );
       }

       elementMiniNode.checkSemantics ( parentMiniNodeStack );

       parentMiniNodeStack.pop ( );
     }

     //////////////////////////////////////////////////////////////////////
     //////////////////////////////////////////////////////////////////////
     }
